#!/bin/bash
#
# author           : Pedro Pinto (pnboy~AT~pinguix.com)
# latest update    : 16-06-2007
# source location  : http://irda.sourceforge.net/
# url              : http://switch.dl.sourceforge.net/sourceforge/irda/irda-utils-0.9.18.tar.gz

NAME=irda-utils
VERSION=0.9.18
ARCH=${ARCH:-i486}
CPU=${CPU:-i686}
BUILD=${BUILD:-48.1}
TMP=${TMP:-/tmp}
PKG=$TMP/package-$NAME
CWD=`pwd`
EXTENSION=tar.gz
FILENAME=$NAME-$VERSION.$EXTENSION

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
#numjobs='-j2'

rm -rf $PKG
mkdir -p $PKG

cd $TMP
rm -rf ${FILENAME/.$EXTENSION/}
  if [ -f $FILENAME ]; then
          echo "Source file already here, no need to re-download";
  elif [ -f $CWD/$FILENAME ]; then
          echo -n "Relocating source file to $TMP..."
          cp $CWD/$FILENAME $TMP/
          echo "done"
  else
          wget -c http://switch.dl.sourceforge.net/sourceforge/irda/$FILENAME
  fi
  tar xf $FILENAME

cd ${FILENAME/.$EXTENSION/}

# Configure:
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
sed -i -e 's/DIRS = irattach irdaping etc man irnetd psion tekram findchip irdadump smcinit/DIRS = irattach irdaping etc man irnetd psion tekram findchip irdadump/g' Makefile
sed -i -e 's/install irnetd \/usr\/sbin\//install irnetd $(ROOT)\/usr\/sbin\//g' irnetd/Makefile

# Build and install:
make V=1 prefix=/usr RPM_OPT_FLAGS="${CFLAGS}" RPM_BUILD_ROOT="${PKG}" ROOT="${PKG}" || exit 1
mkdir -p $PKG/usr/sbin
mkdir -p $PKG/usr/bin
make V=1 install RPM_OPT_FLAGS="${CFLAGS}" RPM_BUILD_ROOT="${PKG}" ROOT="${PKG}" PREFIX="${PKG}" || exit 1

# /etc
mkdir -p $PKG/etc/rc.d

# Configuration
cp etc/irda.sysconfig $PKG/etc/irda.new
sed -i -e 's/DEVICE=\/dev\/ttyS2/DEVICE=\/dev\/ttyS1/g' $PKG/etc/irda.new

# rc.irda
cat << "EOF" > /$PKG/etc/rc.d/rc.irda.new
#!/bin/sh
#
# (c) 2007 Pedro Pinto <pnboy~AT~pinguix.com>
# rc.irda for Zenwalk
# distributed under GPL License

[ -f /usr/sbin/irattach ] || exit 0

pid="$(pidof irattach 2> /dev/null)"

case "$1" in
  start)
	if [ -f /etc/irda ] && [ -z ${pid} ] ; then
		# Source IrDA networking configuration.
		. /etc/irda
		ARGS=
		if [ $DONGLE ]; then
			ARGS="$ARGS -d $DONGLE"
		fi
		if [ "$DISCOVERY" = "yes" ];then
			ARGS="$ARGS -s"
		fi
		/usr/sbin/irattach ${DEVICE} ${ARGS}
	else
		echo "rc.irda is already started."
	fi
	;;
  stop)
	if [ ! -z ${pid} ] ; then
		killall irattach
	else
		echo "rc.irda is not running."
	fi
	;;
  restart)
	$0 stop
	sleep 1
	$0 start
	;;
  *)
	echo "Usage: rc.irda {start|stop|restart}"
	exit 1
esac
exit 0
EOF

# Strip binaries:
( cd $PKG
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress the man page(s)
if [ -d $PKG/usr/man ]; then
        find $PKG/usr/man -type f -name "*.?" -exec gzip -9f {} \;
fi
if [ -d $PKG/usr/info ]; then
        find $PKG/usr/info -type f -name "*.info*" -exec gzip -9f {} \;
fi

# Add a documentation directory:
mkdir -p $PKG/usr/doc/$NAME-$VERSION

# The Makefile evidently contains the package's license...
DOCS="README"
cd $TMP/$NAME-$VERSION
for dir in irattach irdadump; do
    cp -a $dir/ChangeLog $PKG/usr/doc/$NAME-$VERSION/ChangeLog.$dir
done
for dir in ethereal irattach irdadump irdaping irsockets tekram; do
    cp -a $dir/README $PKG/usr/doc/$NAME-$VERSION/README.$dir
done
cp -a \
  $DOCS \
  $PKG/usr/doc/$NAME-$VERSION

#
# as per package rules: add the build-file itself
#
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

mkdir -p $PKG/install

# doinst.sh
cat <<"EOF" > $PKG/install/doinst.sh
config() {
  NEW="$1.new"
  OLD="$1"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for netpkg to consider...
}
config etc/rc.d/rc.irda
config etc/irda
EOF

#    |-----handy-ruler------------------------------------------------------|
echo "$NAME: $NAME (IrDA Utilities)
$NAME:
$NAME: The irda-utils package contains a collection of programs that enable
$NAME: the use of IrDA protocols. Most IrDA features are implemented in the
$NAME: kernel, so IrDA support must be enabled in the kernel before any IrDA
$NAME: tools or programs can be used. Some configuration outside the kernel
$NAME: is required, however, and some IrDA features, like IrOBEX, are
$NAME: actually implemented outside the kernel.
$NAME:
$NAME:
$NAME: " > $PKG/install/slack-desc

#
# real packaging work:
#
# Make sure ownerships and permissions are sane:
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n ../$NAME-$VERSION-$ARCH-$BUILD.tgz

#
# computes the md5sum signature for the package
#
cd $TMP
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5
requiredbuilder -z $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.dep

